<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>CodecConfigs</name>
    <message>
        <location filename="../qml/CodecConfigs.qml" line="27"/>
        <source>Configure %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/CodecConfigs.qml" line="108"/>
        <source>Search option</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/CodecConfigs.qml" line="122"/>
        <source>Reset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/CodecConfigs.qml" line="138"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/CodecConfigs.qml" line="149"/>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StreamOptions</name>
    <message>
        <location filename="../qml/StreamOptions.qml" line="27"/>
        <source>Stream #%1 (%2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/StreamOptions.qml" line="28"/>
        <source>Stream #%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/StreamOptions.qml" line="63"/>
        <source>Codec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/StreamOptions.qml" line="84"/>
        <source>Bitrate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/StreamOptions.qml" line="104"/>
        <source>GOP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/StreamOptions.qml" line="109"/>
        <source>Separation between keyframes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/StreamOptions.qml" line="125"/>
        <source>Advanced Codec Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/StreamOptions.qml" line="150"/>
        <source>Size of the audio (bits) / duration (seconds)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/StreamOptions.qml" line="171"/>
        <source>Size of the video (bits) / duration (seconds)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../qml/main.qml" line="163"/>
        <source>Output format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="192"/>
        <source>File extensions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="198"/>
        <source>This output format has not specific extensions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="203"/>
        <source>Advanced Format Options</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
